Learn R Programming

SDT (version 1.0.0)

print.sdi: Print Method for Objects of Class sdi

Description

S3 method to print objects of the class sdi.

Usage

# S3 method for sdi
print(x, ...)

Arguments

x

A required object of the class sdi, obtained from a call to the function sdi.

Further arguments to be passed are ignored in this function.

Value

If the argument x is of required type, print.sdi prints the original or adjusted SDI or RAI overall index values and returns an invisible copy of these scores.

Details

This print method prints the main results obtained from calculating the original or adjusted SDI or RAI index, which are the overall index values or SDI or RAI scores. The output can be long, and thus, entries may be omitted.

References

Uenlue, A. (2016) Adjusting potentially confounded scoring protocols for motivation aggregation in organismic integration theory: An exemplification with the relative autonomy or self-determination index. Frontiers in Educational Psychology, 7(272), 1--4. URL https://doi.org/10.3389/fpsyg.2016.00272.

See Also

The main function of the package, which creates objects of the class sdi: sdi for the original and adjusted SDI or RAI index. plot.sdi, the S3 method for plotting objects of the class sdi; summary.sdi, the S3 method for summarizing objects of the class sdi. See also SDT-package for general information about this package.

Examples

Run this code
# NOT RUN {
## attach dataset to search path (to use variable names)
attach(learning_motivation)

## adjusted index print
padj <- print(sdi(intrinsic, identified, introjected, external))
## compactly displayed structure of the object padj
str(padj)

## original index print
sdi(intrinsic, identified, introjected, external, compute.adjusted = FALSE)
# }

Run the code above in your browser using DataLab